package com.ruoyi.kaohe.mapper;

import java.util.List;
import com.ruoyi.kaohe.domain.KhVoteRecard;

/**
 * 投票记录Mapper接口
 * 
 * @author hs
 * @date 2025-06-17
 */
public interface KhVoteRecardMapper 
{
    /**
     * 查询投票记录
     * 
     * @param id 投票记录主键
     * @return 投票记录
     */
    public KhVoteRecard selectKhVoteRecardById(Long id);

    /**
     * 查询投票记录列表
     * 
     * @param khVoteRecard 投票记录
     * @return 投票记录集合
     */
    public List<KhVoteRecard> selectKhVoteRecardList(KhVoteRecard khVoteRecard);

    /**
     * 新增投票记录
     * 
     * @param khVoteRecard 投票记录
     * @return 结果
     */
    public int insertKhVoteRecard(KhVoteRecard khVoteRecard);

    /**
     * 修改投票记录
     * 
     * @param khVoteRecard 投票记录
     * @return 结果
     */
    public int updateKhVoteRecard(KhVoteRecard khVoteRecard);

    /**
     * 删除投票记录
     * 
     * @param id 投票记录主键
     * @return 结果
     */
    public int deleteKhVoteRecardById(Long id);

    /**
     * 批量删除投票记录
     * 
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteKhVoteRecardByIds(Long[] ids);
}
